@@ -3,9 +3,12 @@ from swagger_generator.insert import *
 from swagger_generator import util
 from swagger_generator import swagger_info
 from swagger_generator.template_arg import TemplateArg
+from swagger_generator.data_type import DataType
 
 
 import sys
-assert sys.version_info >= (3, 7)
 
-__version__ = "1.0.3"
\ No newline at end of file
+if sys.version_info < (3, 7):
+    raise Exception("Must be using at least Python 3.7")
+
+__version__ = "1.0.5"
\ No newline at end of file
